==> massxpert3_10.4.0.orig.tar.gz: massxpert3-10.4.0/src/gui/AboutDlg.hpp <==
/* BEGIN software license
 *
 * MsXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2026 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the MsXpertSuite project.
 *
 * The MsXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
 * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once

/////////////////////// stdlib includes


/////////////////////// Qt includes
#include <QDialog>
#include <QGraphicsScene>


/////////////////////// pappsomspp includes


/////////////////////// libXpertMass includes


/////////////////////// libXpertMassGui includes


/////////////////////// Local includes


namespace Ui
{
class AboutDlg;
}

namespace MsXpS
{
namespace MassXpert
{


class AboutDlg : public QDialog
{
  Q_OBJECT

  friend class ProgramWindow;

  public:
  explicit AboutDlg(QWidget *parent,
                    const QString &application_name = "MassXpert3");

  ~AboutDlg();

  void setApplicationFeaturesText();
  void makeUserManualCommandLinkConnections();
  void setHistoryText();

  protected:
  QString m_applicationName;

  ::Ui::AboutDlg *m_ui;

  // Allocated but ownership taken by the graphicsView.
  QGraphicsScene *mp_graphicsScene;

  void setupGraphicsView();
  void showHowToCiteTab();
};


} // namespace MassXpert

} // namespace MsXpS

==> massxpert_7.0.0.orig.tar.gz: massxpert-7.0.0/src/gui/AboutDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


/////////////////////// Qt includes
#include <QDialog>
#include <QGraphicsScene>


/////////////////////// Local includes
#include "ui_AboutDlg.h"


namespace msxps
{
namespace massxpert
{


class AboutDlg : public QDialog
{
  Q_OBJECT

		friend class MainWindow;

  private:
  public:
  AboutDlg(QWidget *parent, const QString &applicationName = "massXpert");

  ~AboutDlg();

  void setApplicationFeaturesText();
  void makeUserManualCommandLinkConnections();
  void setHistoryText();

  protected:
  QString m_applicationName;

  Ui::AboutDlg m_ui;

  // Allocated but ownership taken by the graphicsView.
  QGraphicsScene *mp_graphicsScene;

  void setupGraphicsView();
  void showHowToCiteTab();
};


} // namespace massxpert

} // namespace msxps
